@@ -44,7 +44,7 @@ from utils.file_utils.file_convert import *
 from utils.file_utils.file_search import *
 from utils.file_utils.file_compression import *
 
-from utils.file_utils.File import *
+# from utils.file_utils.File import *
 from utils.file_utils.file_utils import *
 from utils.file_utils.resources import *
 import utils.file_utils.exiftool as _exiftool
