@@ -13,7 +13,7 @@
     `memberOf`: file_utils
 '''
 
-
+from typing import Union as _Union
 import json as _json
 # import os as _os
 import re as _re
@@ -101,19 +101,56 @@ def as_json(file_path:str):
     return False
 
 
+def as_template(file_path:str,replacements:dict)->_Union[str,None]:
+    '''
+        Read a file as a string and replace all keys with their values from the replacements dict.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The path to the template file.
+        `replacements` {dict}
+            A dictionary to replace placeholders in the template file with.
+
+        Return {str|None}
+        ----------------------
+        The string if successful, None otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-29-2022 05:10:19
+        `memberOf`: file_read
+        `version`: 1.0
+        `method_name`: as_template
+        * @xxx [06-29-2022 05:18:17]: documentation for as_template
+    '''
+
+    contents = readr(file_path)
+    contents = _csu.dict_replace_string(contents,replacements)
+    return contents
+
 def __parse_json_comments(file_path:str):
     '''
         strips comments from a json file.
 
         @return The contents of the file as a string.
     '''
-    file_array = data_array(file_path)
-    output_array = []
-    for file in file_array:
-        match = _re.search(r'^\s*\/\/', file['raw_content'])
-        if match is None:
-            output_array.append(file)
-    return file_content_data_to_string(output_array)
+    contents = readr(file_path)
+    # file_array = data_array(file_path)
+    # output_array = []
+    # for file in file_array:
+    #     match = _re.search(r'^\s*\/\/', file['raw_content'])
+    #     if match is None:
+    #         output_array.append(file)
+    # contents = file_content_data_to_string(output_array)
+    # strip single line comments
+    contents = _re.sub(r'\/\/[^\n\r]+',"",contents,0,_re.MULTILINE)
+    # strip multiline comments
+    contents = _re.sub(r'(\/\*[\s\S]*?\*\/)',"",contents,0,_re.MULTILINE)
+    return contents
 
 
 def data_array(file_path:str):
