@@ -14,6 +14,7 @@
     `memberOf`: random_utils
 '''
 
+import re as _re
 import random as _random
 import exrex as _exrex
 import hashlib as _hashlib
@@ -178,6 +179,37 @@ def rand(length=12, **kwargs):
 
     return ''.join(_random.SystemRandom().choice(choices) for _ in range(length))
 
+def css_class(length=12):
+    '''
+        Generate a random string that is safe to use as a css class.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `length` {int}
+            How long the string should be.
+
+        Return {str}
+        ----------------------
+        The randomly generate class string.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-29-2022 14:45:19
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: css_class
+        * @xxx [07-29-2022 14:46:00]: documentation for css_class
+    '''
+
+
+    value = rand(length)
+    value = _re.sub(r'^[0-9]',"x",value)
+    return value
+
+
 def text(minimum=10,maximum=500,null_bias=0):
     '''
         Wrapper method for faker().text()
