@@ -31,6 +31,41 @@ _VALID_PYTHON_TYPES = {
     "dict":["dictionary","dict"],
     "boolean":["boolean","bool"]
 }
+_VALID_PHP_TYPES = {
+    "string":["string","str","text","varchar","mediumtext","tinytext","longtext","char",],
+    "int":["integer","number","int","tinyint","mediumint","smallint","bigint","dec",],
+    "float":["float","double","decimal"],
+    "array":["list","array","dictionary","dict","tuple","set"],
+    "bool":["boolean","bool"],
+    "null":["null","none"],
+}
+
+
+# _sql_data_types = [
+#     "mediumblob",
+#     "varbinary",
+#     "timestamp",
+#     "tinyblob",
+#     "longblob",
+#     "datetime",
+#     "binary",
+#     "year",
+#     "time",
+#     "enum",
+#     "date",
+#     "blob",
+#     "set",
+#     "dec",
+#     "bit",
+# ]
+
+
+def type_to_php(value:str)->str:
+    value = value.lower()
+    for k,v in _VALID_PHP_TYPES.items():
+        if value in v:
+            return k
+    return None
 
 def determine_boolean(value:str, def_val=None)->bool:
     '''
